# osmNetwork

![CI](https://github.com/amauryval/osmNetwork/workflows/RunTest/badge.svg)

[![codecov](https://codecov.io/gh/amauryval/osmNetwork/branch/master/graph/badge.svg)](https://codecov.io/gh/amauryval/osmNetwork)


## Dev Env install

```bash
pyenv local 3.11.0
poetry env use 3.11.0
poetry install
```
